==> loopback4-authentication-9.0.2.tgz: package/src/strategies/passport/passport-client-password/client-password-strategy-factory-provider.ts <==
import {inject, Provider} from '@loopback/core';
import {HttpErrors, Request} from '@loopback/rest';
import * as ClientPasswordStrategy from './client-password-strategy';

import {AuthErrorKeys} from '../../../error-keys';
import {IAuthClient} from '../../../types';
import {Strategies} from '../../keys';
import {VerifyFunction} from '../../types';

export interface ClientPasswordStrategyFactory {
  (
    options?: ClientPasswordStrategy.StrategyOptionsWithRequestInterface,
    verifierPassed?: VerifyFunction.OauthClientPasswordFn,
  ): ClientPasswordStrategy.Strategy;
}

export class ClientPasswordStrategyFactoryProvider
  implements Provider<ClientPasswordStrategyFactory>
{
  constructor(
    @inject(Strategies.Passport.OAUTH2_CLIENT_PASSWORD_VERIFIER)
    private readonly verifier: VerifyFunction.OauthClientPasswordFn,
  ) {}

  value(): ClientPasswordStrategyFactory {
    return (options, verifier) =>
      this.getClientPasswordVerifier(options, verifier);
  }

  clientPasswordVerifierHelper(
    client: IAuthClient | null,
    clientSecret: string | undefined,
  ) {
    if (!client?.clientSecret || client.clientSecret !== clientSecret) {
      throw new HttpErrors.Unauthorized(AuthErrorKeys.ClientVerificationFailed);
    } else {
      // do nothing
    }
  }

  getClientPasswordVerifier(
    options?: ClientPasswordStrategy.StrategyOptionsWithRequestInterface,
    verifierPassed?: VerifyFunction.OauthClientPasswordFn,
  ): ClientPasswordStrategy.Strategy {
    const verifyFn = verifierPassed ?? this.verifier;
    if (options?.passReqToCallback) {
      return new ClientPasswordStrategy.Strategy(
        // eslint-disable-next-line @typescript-eslint/no-misused-promises
        async (
          clientId: string,
          clientSecret: string | undefined,
          cb: (err: Error | null, client?: IAuthClient | null) => void,
          req: Request | undefined,
        ) => {
          try {
            const client = await verifyFn(clientId, clientSecret, req);
            this.clientPasswordVerifierHelper(client, clientSecret);
            cb(null, client);
          } catch (err) {
            cb(err);
          }
        },
        options,
      );
    } else {
      return new ClientPasswordStrategy.Strategy(
        // eslint-disable-next-line @typescript-eslint/no-misused-promises
        async (
          clientId: string,
          clientSecret: string | undefined,
          cb: (err: Error | null, client?: IAuthClient | null) => void,
        ) => {
          try {
            const client = await verifyFn(clientId, clientSecret);
            this.clientPasswordVerifierHelper(client, clientSecret);
            cb(null, client);
          } catch (err) {
            cb(err);
          }
        },
      );
    }
  }
}

==> loopback4-authentication-11.0.1.tgz: package/src/strategies/passport/passport-client-password/client-password-strategy-factory-provider.ts <==
// SONAR-IGNORE-ALL
import {inject, Provider} from '@loopback/core';
import {HttpErrors, Request} from '@loopback/rest';
// eslint-disable-next-line @typescript-eslint/naming-convention
import * as ClientPasswordStrategy from './client-password-strategy';

import {AuthErrorKeys} from '../../../error-keys';
import {IAuthClient} from '../../../types';
import {Strategies} from '../../keys';
import {VerifyFunction} from '../../types';

export type ClientPasswordStrategyFactory = (
  options?: ClientPasswordStrategy.StrategyOptionsWithRequestInterface,
  verifierPassed?: VerifyFunction.OauthClientPasswordFn,
) => ClientPasswordStrategy.Strategy;

export class ClientPasswordStrategyFactoryProvider
  implements Provider<ClientPasswordStrategyFactory>
{
  constructor(
    @inject(Strategies.Passport.OAUTH2_CLIENT_PASSWORD_VERIFIER)
    private readonly verifier: VerifyFunction.OauthClientPasswordFn,
  ) {}

  value(): ClientPasswordStrategyFactory {
    return (options, verifier) =>
      this.getClientPasswordVerifier(options, verifier);
  }

  clientPasswordVerifierHelper(
    client: IAuthClient | null,
    clientSecret: string | undefined,
  ) {
    if (!client?.clientSecret || client.clientSecret !== clientSecret) {
      throw new HttpErrors.Unauthorized(AuthErrorKeys.ClientVerificationFailed);
    } else {
      // do nothing
    }
  }
  //prettier-ignore-start
  // prettier-ignore
  getClientPasswordVerifier(
    options?: ClientPasswordStrategy.StrategyOptionsWithRequestInterface,
    verifierPassed?: VerifyFunction.OauthClientPasswordFn,
  ): ClientPasswordStrategy.Strategy {
    const verifyFn = verifierPassed ?? this.verifier;
    if (options?.passReqToCallback) {
      return new ClientPasswordStrategy.Strategy(
        (
          clientId: string,
          clientSecret: string | undefined,
          cb: (err: Error | null, client?: IAuthClient | null) => void,
          req: Request | undefined,
        ) => {
          verifyFn(clientId, clientSecret, req)
            .then(client => {
              this.clientPasswordVerifierHelper(client, clientSecret);
              cb(null, client);
            })
            .catch(err => {
              cb(err);
            });
        },
        options,
      );
    } else {
      return new ClientPasswordStrategy.Strategy(
        (
          clientId: string,
          clientSecret: string | undefined,
          cb: (err: Error | null, client?: IAuthClient | null) => void,
        ) => {
          verifyFn(clientId, clientSecret)
            .then(client => {
              this.clientPasswordVerifierHelper(client, clientSecret);
              cb(null, client);
            })
            .catch(err => {
              cb(err);
            });
        },
      );
    }
  }
  //prettier-ignore-end
}
